@@ -23,6 +23,7 @@ class ASCIIDocExporter(TemplateExporter):
         return 'asciidoc'
 
     output_mimetype = 'text/asciidoc'
+    export_from_notebook = "AsciiDoc"
 
     @default('raw_mimetypes')
     def _raw_mimetypes_default(self):
@@ -41,7 +42,10 @@ class ASCIIDocExporter(TemplateExporter):
                                           'text/latex'
                                           ]
             },
-            'ExtractOutputPreprocessor': {'enabled': True}
+            'ExtractOutputPreprocessor': {'enabled': True},
+            'HighlightMagicsPreprocessor': {
+                'enabled':True
+                },
         })
         c.merge(super(ASCIIDocExporter, self).default_config)
         return c
